=== modified file 'setup.py'
--- setup.py	2015-10-13 13:13:35 +0000
+++ setup.py	2015-10-14 18:14:47 +0000
@@ -22,11 +22,6 @@
 from setuptools.command.test import test
 
 
-class TestCommand(test):
-    def run(self):
-        subprocess.check_call(['./runtests.sh'])
-
-
 setup(name="snapcraft",
       version="0",
       description="Easily craft snaps",
@@ -40,5 +35,5 @@
           ('share/snapcraft/schema',
               ['schema/' + x for x in os.listdir('schema')]),
       ],
-      cmdclass={'test': TestCommand},
+      test_suite='snapcraft.tests',
       )

=== modified file 'snapcraft/sources.py'
--- snapcraft/sources.py	2015-10-08 18:08:57 +0000
+++ snapcraft/sources.py	2015-10-14 18:14:47 +0000
@@ -17,6 +17,7 @@
 import logging
 import os
 import os.path
+import requests
 import shutil
 import tarfile
 import re
@@ -25,6 +26,7 @@
 
 
 logger = logging.getLogger(__name__)
+logging.getLogger('urllib3').setLevel(logging.CRITICAL)
 
 
 class IncompatibleOptionsError(Exception):
@@ -143,12 +145,20 @@
                 'can\'t specify a source-branch for a tar source')
 
     def pull(self):
-        if snapcraft.common.isurl(self.source):
-            return snapcraft.common.run(['wget', '-q', '-c', self.source],
-                                        cwd=self.source_dir)
-        else:
+        if not snapcraft.common.isurl(self.source):
             return True
 
+        req = requests.get(self.source, stream=True, allow_redirects=True)
+        if req.status_code is not 200:
+            return False
+
+        file = os.path.join(self.source_dir, os.path.basename(self.source))
+        with open(file, 'wb') as f:
+            for chunk in req.iter_content(1024):
+                f.write(chunk)
+
+        return True
+
     def provision(self, dst, clean_target=True):
         # TODO add unit tests.
         if snapcraft.common.isurl(self.source):

=== modified file 'snapcraft/tests/test_sources.py'
--- snapcraft/tests/test_sources.py	2015-10-05 18:53:44 +0000
+++ snapcraft/tests/test_sources.py	2015-10-14 18:14:47 +0000
@@ -41,7 +41,9 @@
 class TestTar(tests.TestCase):
 
     def test_pull_tarball_must_download_to_sourcedir(self):
-        server = http.server.HTTPServer(('', 0), FakeTarballHTTPRequestHandler)
+        os.environ['no_proxy'] = '127.0.0.1'
+        server = http.server.HTTPServer(
+            ('127.0.0.1', 0), FakeTarballHTTPRequestHandler)
         server_thread = threading.Thread(target=server.serve_forever)
         self.addCleanup(server_thread.join)
         self.addCleanup(server.server_close)
@@ -56,7 +58,7 @@
             *server.server_address, file_name=tar_file_name)
         tar_source = sources.Tar(source, dest_dir)
 
-        tar_source.pull()
+        self.assertTrue(tar_source.pull())
 
         with open(os.path.join(dest_dir, tar_file_name), 'r') as tar_file:
             self.assertEqual('Test fake tarball file', tar_file.read())

